@@ -66,6 +66,7 @@ Generic interface for a backend database:
 :parameter name: name of database, such as **redis**, **couchdb**, etc..
 :parameter params: dictionary of configuration parameters
 :parameter pickler: calss for serializing and unserializing data.
+
 It must implement the *loads* and *dumps* methods.'''
     Transaction = None
     Query = None
@@ -117,7 +118,9 @@ Save or updated an instance of a model to the back-end database:
         
 :parameter obj: instance of :ref:`StdModel <model-model>`
                 to add/update to the database
-:parameer transaction: optional transaction instance.'''
+:parameer transaction: optional transaction instance.
+
+Raises :class:`stdnet.FieldValueError` if the instance is not valid.'''
         commit = False
         if not transaction:
             commit = True
@@ -125,7 +128,7 @@ Save or updated an instance of a model to the back-end database:
             
         # Save the object in the back-end
         if not obj.is_valid():
-            raise FieldError(json.dumps(obj.errors))
+            raise FieldValueError(json.dumps(obj.errors))
         
         # We are updating the object,
         # therefore we need to clean up indexes first
@@ -149,6 +152,7 @@ Save or updated an instance of a model to the back-end database:
     def delete_object(self, obj, transaction = None):
         '''Delete an object from the data server and clean up indices.
 Called to clear a model instance.
+
 :parameter obj: instance of :class:`stdnet.orm.StdModel`
 :parameter deleted: a list or ``None``. If a list, deleted keys
                     will be appended to it.
