@@ -55,6 +55,31 @@ class WordItem(orm.StdModel):
         return self._object
     
 
+class Tag(Word):
+    pass
+
+
+class TagItem():
+    '''A model for associating :class:`Word` instances with general
+:class:`stdnet.orm.StdModel` instances.'''
+    tag = orm.ForeignKey(Tag, related_name = 'items')
+    '''tag instance'''
+    model_type = orm.ModelField()
+    '''Model type'''
+    object_id = orm.SymbolField()
+    '''Model instance id'''
+    
+    def __unicode__(self):
+        return self.word.__unicode__()
+    
+    @property
+    def object(self):
+        '''Instance of :attr:`model_type` with id :attr:`object_id`.'''
+        if not hasattr(self,'_object'):
+            self._object = self.model_type.objects.get(id = self.object_id)
+        return self._object
+    
+    
 class AutoComplete(orm.StdModel):
     '''A model which should be used as signletone::
     
