@@ -163,8 +163,9 @@ The key is an encoded binary string. For example::
         return self.basekey('ids')
     
     def is_valid(self, instance):
-        '''Perform validation and stores serialized data, indexes and errors.
-Return ``True`` is the instance is ready to be saved to database.'''
+        '''Perform validation for *instance* and stores serialized data,
+indexes and errors into local cache.
+Return ``True`` if the instance is ready to be saved to database.'''
         v = {}
         setattr(instance,self.VALATTR,v)
         data = v['data'] = {}
@@ -173,17 +174,26 @@ Return ``True`` is the instance is ready to be saved to database.'''
         #Loop over scalar fields first
         for field in self.scalarfields:
             name = field.attname
-            svalue = field.serialize(getattr(instance,name,None))
-            if (svalue is None or svalue is '') and field.required:
-                errors[name] = "Field '{0}' is required for '{1}'.".format(name,self)
+            value = getattr(instance,name,None)
+            if value is None:
+                value = field.get_default()
+                setattr(instance,name,value)
+            try:
+                svalue = field.serialize(value)
+            except FieldValueError as e:
+                errors[name] = str(e)
             else:
-                if isinstance(svalue, dict):
-                    data.update(svalue)
+                if (svalue is None or svalue is '') and field.required:
+                    errors[name] = "Field '{0}' is required for '{1}'."\
+                                    .format(name,self)
                 else:
-                    if svalue is not None:
-                        data[name] = svalue
-                    if field.index:
-                        indexes.append((field,svalue))
+                    if isinstance(svalue, dict):
+                        data.update(svalue)
+                    else:
+                        if svalue is not None:
+                            data[name] = svalue
+                        if field.index:
+                            indexes.append((field,svalue))
         return len(errors) == 0
                 
     def table(self, transaction = None):
@@ -229,9 +239,7 @@ the model table'''
  It is not a scalar field.'.format(sortby))
 
 class FakeMeta(object):
-    
-    def __init__(self, hash):
-        self.hash = hash
+    pass
         
     
 class FakeModelType(type):
@@ -242,10 +250,9 @@ class FakeModelType(type):
         new_class = super(FakeModelType, cls).__new__(cls, name, bases, attrs)
         if not parents or is_base_class:
             return new_class
+        new_class._meta = FakeMeta()
         hashmodel(new_class)
-        new_class._meta = FakeMeta(new_class.hash)
-        delattr(new_class,'hash')
-        return new_class        
+        return new_class  
 
 
 class StdNetType(type):
