@@ -1,5 +1,6 @@
 from stdnet.exceptions import *
 from stdnet import pipelines
+from stdnet.utils import encoders
 from stdnet.orm.related import add_lazy_relation, ModelFieldPickler
 
 from .fields import Field, RelatedObject
@@ -31,7 +32,8 @@ class ManyFieldManagerProxy(GetStructureMixin):
         if instance is None:
             return self
         if instance.id is None:
-            raise MultiFieldError('id for %s is not available. Call save on instance before accessing %s.' % (instance._meta,self.name))
+            raise MultiFieldError('id for %s is not available.\
+ Call save on instance before accessing %s.' % (instance._meta,self.name))
         cache_name = self.get_cache_name()
         try:
             return getattr(instance, cache_name)
@@ -47,7 +49,8 @@ class ManyFieldManagerProxy(GetStructureMixin):
 class Many2ManyManagerProxy(ManyFieldManagerProxy):
     
     def __init__(self, name, stype, to_name, to):
-        super(Many2ManyManagerProxy,self).__init__(name, stype, ModelFieldPickler(to), None, None)
+        super(Many2ManyManagerProxy,self).__init__(
+                        name, stype, ModelFieldPickler(to), None, None)
         self.to_name = to_name
         self.to = to
         
@@ -61,7 +64,8 @@ class MultiField(Field):
     
 .. attribute:: relmodel
 
-    Optional :class:`stdnet.otm.StdModel` class contained in the structure. It can also be specified as a string.
+    Optional :class:`stdnet.otm.StdModel` class contained in the structure.
+    It can also be specified as a string.
     
 .. attribute:: related_name
 
@@ -69,13 +73,21 @@ class MultiField(Field):
     
 .. attribute:: pickler
 
-    a module/class/objects used to serialize values. Default ``None``.
+    a module/class/objects used to serialize values.
+    
+    Default ``None``.
     
 .. attribute:: converter
 
-    a module/class/objects used to convert keys to suitable string to use as keys in :class:`stdnet.HashTable` structures.
+    a module/class/objects used to convert keys to suitable string to use
+    as keys in :class:`stdnet.HashTable` structures.
     It must implement two methods, ``tokey`` to convert key to a suitable key
-    for the database backend and ``tovalue`` the inverse operation. Default: ``None``.'''
+    for the database backend and ``tovalue`` the inverse operation.
+    
+    Default: ``None``.
+'''
+    default_pickler = encoders.Json()
+    
     def get_pipeline(self):
         raise NotImplementedError
     
@@ -94,8 +106,8 @@ class MultiField(Field):
         self.index        = False
         self.unique       = False
         self.primary_key  = False
-        self.related_name = related_name  
         self.pickler      = pickler
+        self.related_name = related_name
         self.converter    = converter
         self.scorefun     = scorefun
         
@@ -108,12 +120,15 @@ class MultiField(Field):
             
     def _register_related_model(self, field, related):
         field.relmodel = related
-        if related:
-            if not field.pickler:
-                field.pickler = ModelFieldPickler(related)
+        if related and not field.pickler:
+            field.pickler = ModelFieldPickler(related)
+        if not field.pickler:
+            field.pickler = self.default_pickler
         setattr(self.model,
                 self.name,
-                ManyFieldManagerProxy(self.name,self.get_pipeline(),self.pickler,self.converter,self.scorefun))
+                ManyFieldManagerProxy(self.name,self.get_pipeline(),
+                                      self.pickler,self.converter,
+                                      self.scorefun))
 
     def add_to_fields(self):
         self.model._meta.multifields.append(self)
@@ -128,8 +143,8 @@ class MultiField(Field):
 class SetField(MultiField):
     '''A field maintaining an unordered collection of values. It is initiated
 without any argument other than an optional model class.
-When accessed from the model instance, it returns an instance of :class:`stdnet.Set` structure.
-For example::
+When accessed from the model instance, it returns an instance of
+:class:`stdnet.Set` structure. For example::
 
     class User(orm.StdModel):
         username  = orm.AtomField(unique = True)
@@ -151,7 +166,8 @@ It can be used in the following way::
     
 
 class ListField(MultiField):
-    '''A field maintaining a list of values. When accessed from the model instance,
+    '''A field maintaining a list of values.
+When accessed from the model instance,
 it returns an instance of :class:`stdnet.List` structure. For example::
 
     class UserMessage(orm.StdModel):
@@ -190,7 +206,8 @@ it returns an instance of :class:`stdnet.HashTable` structure.
 
 
 class ManyToManyField(MultiField):
-    '''A many-to-many relationship. It accepts **related_name** as extra argument.
+    '''A many-to-many relationship. It accepts **related_name**
+as extra argument.
 
 .. attribute:: related_name
 
@@ -231,6 +248,8 @@ This field is implemented as a double Set field.
         self.related_name = related_name
         field.relmodel = related
         stype = self.get_pipeline()
-        setattr(self.model,  self.name,    Many2ManyManagerProxy(self.name,    stype, related_name, related))
-        setattr(self.relmodel,related_name,Many2ManyManagerProxy(related_name, stype, self.name, self.model))
+        setattr(self.model, self.name, Many2ManyManagerProxy(self.name,
+                            stype, related_name, related))
+        setattr(self.relmodel,related_name,Many2ManyManagerProxy(related_name,
+                                        stype, self.name, self.model))
            
