@@ -4,11 +4,14 @@ from datetime import datetime
 from stdnet.lib.py2py3.py2py3 import *
 if ispy3k:
     import pickle
+    from io import BytesIO
+    unichr = chr
 else:
     import cPickle as pickle
+    from cStringIO import StringIO as BytesIO
+    unichr = unichr 
+    
 
-#from .encoding import *
-from .rwlock import *
 from .jsontools import *
 from .populate import populate
 from .fields import *
